@@ -1,4 +1,3 @@
-# flake8: noqa
 from perun.connector.adapters.AdapterInterface import AdapterInterface
 from perun.connector.adapters.AdaptersManager import AdaptersManager
 from perun.connector.adapters.LdapAdapter import AdapterSkipException
@@ -13,3 +12,20 @@ from perun.connector.models.Resource import Resource
 from perun.connector.models.UserExtSource import UserExtSource
 from perun.connector.models.MemberStatusEnum import MemberStatusEnum
 from perun.connector.models.HasIdAbstract import HasIdAbstract
+
+__all__ = [
+    "AdapterInterface",
+    "AdaptersManager",
+    "AdapterSkipException",
+    "Logger",
+    "AttributeUtils",
+    "VO",
+    "User",
+    "Group",
+    "Member",
+    "Facility",
+    "Resource",
+    "UserExtSource",
+    "MemberStatusEnum",
+    "HasIdAbstract",
+]
