@@ -121,7 +121,7 @@ class LdapAdapter(AdapterInterface):
         return VO(vo_id or int(vo["perunVoId"]), vo["description"][0], vo["o"][0])
 
     def get_member_groups(
-            self, user: Union[User, int], vo: Union[VO, int]
+        self, user: Union[User, int], vo: Union[VO, int]
     ) -> List[Group]:
         user_id = AdapterInterface.get_object_id(user)
         vo_id = AdapterInterface.get_object_id(vo)
@@ -164,8 +164,6 @@ class LdapAdapter(AdapterInterface):
             + "))",
             ["perunResourceId", "assignedGroupId", "perunVoId"],
         )
-        groups = []
-        unique_ids = []
 
         if not resources:
             raise LDAPNotExistsException(
@@ -174,30 +172,39 @@ class LdapAdapter(AdapterInterface):
                 + " hasn't assigned any resource."
             )
 
+        groups = set()
         for resource in resources:
-            if "assignedGroupId" in resource:
-                for group_id in resource["assignedGroupId"]:
-                    group = self.connector.search_for_entity(
-                        "perunGroupId="
-                        + group_id
-                        + ",perunVoId="
-                        + resource["perunVoId"]
-                        + ","
-                        + self._ldap_base,
-                        "(objectClass=perunGroup)",
-                        [
-                            "perunGroupId",
-                            "cn",
-                            "perunUniqueGroupName",
-                            "perunVoId",
-                            "uuid",
-                            "description",
-                        ],
-                    )
-                    if group["perunGroupId"] not in unique_ids:
-                        groups.append(self._create_internal_representation_group(group))
+            groups.update(self.__get_assigned_groups_ldap_resource(resource))
+        return list(groups)
 
-                        unique_ids.append(group["perunGroupId"])
+    def __get_assigned_groups_ldap_resource(self, resource) -> List[Group]:
+        vo = self.get_vo(resource["perunVoId"])
+        unique_ids = []
+        groups = []
+
+        if "assignedGroupId" in resource:
+            for group_id in resource["assignedGroupId"]:
+                group = self.connector.search_for_entity(
+                    "perunGroupId="
+                    + group_id
+                    + ",perunVoId="
+                    + resource["perunVoId"]
+                    + ","
+                    + self._ldap_base,
+                    "(objectClass=perunGroup)",
+                    [
+                        "perunGroupId",
+                        "cn",
+                        "perunUniqueGroupName",
+                        "perunVoId",
+                        "uuid",
+                        "description",
+                    ],
+                )
+                if group["perunGroupId"] not in unique_ids:
+                    groups.append(self._create_internal_representation_group(group, vo))
+
+                    unique_ids.append(group["perunGroupId"])
         return groups
 
     def get_sp_groups_by_rp_id(self, rp_id: str) -> List[Group]:
@@ -205,7 +212,7 @@ class LdapAdapter(AdapterInterface):
         return self.get_sp_groups_by_facility(facility)
 
     def get_user_attributes(
-            self, user: Union[User, int], perun_attr_names: List[str]
+        self, user: Union[User, int], perun_attr_names: List[str]
     ) -> dict[str, Union[str, Optional[int], bool, List[str], dict[str, str]]]:
         user_id = AdapterInterface.get_object_id(user)
         if not perun_attr_names:
@@ -216,12 +223,12 @@ class LdapAdapter(AdapterInterface):
         )
 
     def get_entityless_attribute(
-            self, attr_name: str
+        self, attr_name: str
     ) -> Union[str, Optional[int], bool, List[str], dict[str, str]]:
         raise AdapterSkipException()
 
     def get_vo_attributes(
-            self, vo: Union[VO, int], perun_attr_names: List[str]
+        self, vo: Union[VO, int], perun_attr_names: List[str]
     ) -> dict[str, Union[str, Optional[int], bool, List[str], dict[str, str]]]:
         vo_id = AdapterInterface.get_object_id(vo)
         return self._get_attributes(
@@ -255,7 +262,7 @@ class LdapAdapter(AdapterInterface):
         )
 
     def get_users_groups_on_facility(
-            self, facility: Union[Facility, int], user: Union[User, int]
+        self, facility: Union[Facility, int], user: Union[User, int]
     ) -> List[Group]:
 
         if not facility:
@@ -282,7 +289,7 @@ class LdapAdapter(AdapterInterface):
         resources_string = "(|"
         for resource in resources:
             resources_string += (
-                    "(assignedToResourceId=" + resource["perunResourceId"] + ")"
+                "(assignedToResourceId=" + resource["perunResourceId"] + ")"
             )
         resources_string += ")"
         result_groups = []
@@ -315,7 +322,7 @@ class LdapAdapter(AdapterInterface):
         return result_groups
 
     def get_users_groups_on_facility_by_rp_id(
-            self, rp_identifier: str, user: Union[User, int]
+        self, rp_identifier: str, user: Union[User, int]
     ):
         facility = self.get_facility_by_rp_identifier(rp_identifier)
         return self.get_users_groups_on_facility(facility, user)
@@ -324,7 +331,7 @@ class LdapAdapter(AdapterInterface):
         raise AdapterSkipException()
 
     def get_facility_attributes(
-            self, facility: Union[Facility, int], perun_attr_names: List[str]
+        self, facility: Union[Facility, int], perun_attr_names: List[str]
     ):
         facility_id = AdapterInterface.get_object_id(facility)
         return self._get_attributes(
@@ -336,26 +343,26 @@ class LdapAdapter(AdapterInterface):
         raise AdapterSkipException()
 
     def update_user_ext_source_last_access(
-            self, user_ext_source: Union[UserExtSource, int]
+        self, user_ext_source: Union[UserExtSource, int]
     ):
         raise AdapterSkipException()
 
     def get_user_ext_source_attributes(
-            self, user_ext_source: Union[UserExtSource, int], attr_names: List[str]
+        self, user_ext_source: Union[UserExtSource, int], attr_names: List[str]
     ):
         raise AdapterSkipException()
 
     def set_user_ext_source_attributes(
-            self,
-            user_ext_source: Union[UserExtSource, int],
-            attributes: dict[
-                str, Union[str, Optional[int], bool, List[str], dict[str, str]]
-            ],
+        self,
+        user_ext_source: Union[UserExtSource, int],
+        attributes: dict[
+            str, Union[str, Optional[int], bool, List[str], dict[str, str]]
+        ],
     ):
         raise AdapterSkipException()
 
     def get_member_status_by_user_and_vo(
-            self, user: Union[User, int], vo: Union[VO, int]
+        self, user: Union[User, int], vo: Union[VO, int]
     ):
         user_id = AdapterInterface.get_object_id(user)
         vo_id = AdapterInterface.get_object_id(vo)
@@ -373,13 +380,14 @@ class LdapAdapter(AdapterInterface):
 
         if not group_id:
             raise AdapterSkipException(
-                "Member status is other than valid. Skipping to another adapter to get MemberStatus"
+                "Member status is other than valid. "
+                + "Skipping to another adapter to get MemberStatus"
             )
 
         return MemberStatusEnum.VALID
 
     def is_user_in_vo_by_short_name(
-            self, user: Union[User, int], vo_short_name: str
+        self, user: Union[User, int], vo_short_name: str
     ) -> bool:
         user_id = AdapterInterface.get_object_id(user)
         if not user_id:
@@ -391,7 +399,7 @@ class LdapAdapter(AdapterInterface):
         return MemberStatusEnum.VALID == self.get_member_status_by_user_and_vo(user, vo)
 
     def get_resource_capabilities_by_facility(
-            self, facility: Union[Facility, int], user_groups: List[Union[Group, int]]
+        self, facility: Union[Facility, int], user_groups: List[Union[Group, int]]
     ) -> List[str]:
         if not facility:
             return []
@@ -432,13 +440,13 @@ class LdapAdapter(AdapterInterface):
         return resource_capabilities
 
     def get_resource_capabilities_by_rp_id(
-            self, rp_identifier: str, user_groups: List[Union[Group, int]]
+        self, rp_identifier: str, user_groups: List[Union[Group, int]]
     ) -> List[str]:
         facility = self.get_facility_by_rp_identifier(rp_identifier)
         return self.get_resource_capabilities_by_facility(facility, user_groups)
 
     def get_facility_capabilities_by_facility(
-            self, facility: Union[Facility, int]
+        self, facility: Union[Facility, int]
     ) -> List[str]:
         if facility is None:
             return []
@@ -460,10 +468,12 @@ class LdapAdapter(AdapterInterface):
         facility = self.get_facility_by_rp_identifier(rp_identifier)
         return self.get_facility_capabilities_by_facility(facility)
 
-    def _create_internal_representation_group(self, group: dict[str, str]) -> Group:
+    def _create_internal_representation_group(
+        self, group: dict[str, str], vo=None
+    ) -> Group:
         return Group(
             int(group["perunGroupId"]),
-            self.get_vo(vo_id=int(group["perunVoId"])),
+            self.get_vo(vo_id=int(group["perunVoId"])) if not vo else vo,
             group["uuid"],
             group["cn"][0],
             group["perunUniqueGroupName"],
@@ -484,8 +494,8 @@ class LdapAdapter(AdapterInterface):
             return attr_values_dict
 
         for (
-                internal_name,
-                internal_attr_cfg,
+            internal_name,
+            internal_attr_cfg,
         ) in self._attribute_utils.get_specific_attrs_config_dict(
             perun_attr_names
         ).items():
@@ -534,12 +544,12 @@ class LdapAdapter(AdapterInterface):
         return ldap_attr_names
 
     def get_groups_where_member_is_active(
-            self, member: Union[Member, int]
+        self, member: Union[Member, int]
     ) -> List[Group]:
         raise AdapterSkipException()
 
     def get_groups_where_user_as_member_is_active(
-            self, user: Union[User, int], vo: Union[VO, int]
+        self, user: Union[User, int], vo: Union[VO, int]
     ) -> List[Group]:
         raise AdapterSkipException()
 
@@ -556,11 +566,11 @@ class LdapAdapter(AdapterInterface):
         raise AdapterSkipException()
 
     def set_facility_attributes(
-            self,
-            facility: Union[Facility, int],
-            attributes: dict[
-                str, Union[str, Optional[int], bool, List[str], dict[str, str]]
-            ],
+        self,
+        facility: Union[Facility, int],
+        attributes: dict[
+            str, Union[str, Optional[int], bool, List[str], dict[str, str]]
+        ],
     ) -> None:
         raise AdapterSkipException()
 
@@ -568,47 +578,162 @@ class LdapAdapter(AdapterInterface):
         raise AdapterSkipException()
 
     def get_member_by_user(
-            self, user: Union[User, int], vo: Union[VO, int]
+        self, user: Union[User, int], vo: Union[VO, int]
     ) -> Optional[Member]:
         raise AdapterSkipException()
 
     def is_user_perun_admin(self, user: Union[User, int]) -> bool:
         raise AdapterSkipException()
 
-    def get_vos_where_user_is_admin(self, user: Union[User, int], check_perun_admin=False) -> List[VO]:
+    def get_vos_where_user_is_admin(
+        self, user: Union[User, int], check_perun_admin=True
+    ) -> List[VO]:
         raise AdapterSkipException
 
-    def get_groups_where_user_is_admin(self, user: Union[User, int], check_perun_admin=False,
-                                       fill_group_unique_name=False) -> List[Group]:
+    def get_groups_where_user_is_admin(
+        self,
+        user: Union[User, int],
+        check_perun_admin=True,
+        fill_group_unique_name=True,
+    ) -> List[Group]:
         raise AdapterSkipException
 
-    def get_facilities_where_user_is_admin(self, user: Union[User, int], check_perun_admin=False) -> List[Facility]:
+    def get_facilities_where_user_is_admin(
+        self, user: Union[User, int], check_perun_admin=True, fill_facility_rp_id=True
+    ) -> List[Facility]:
         raise AdapterSkipException
 
-    def get_resources_where_user_is_admin(self, user: Union[User, int], check_perun_admin=False) -> List[Resource]:
+    def get_resources_where_user_is_admin(
+        self, user: Union[User, int], check_perun_admin=True, fill_facility_rp_id=True
+    ) -> List[Resource]:
         raise AdapterSkipException
 
     def get_all_vos(self) -> List[VO]:
         vos = self.connector.search_for_entities(
-            self._ldap_base,
-            "(objectClass=perunVo)",
-            ["perunVoId", "o", "description"],
+            self._ldap_base, "(objectClass=perunVo)", ["perunVoId", "o", "description"]
         )
-        return [VO(int(vo["perunVoId"]), vo["description"][0], vo["o"][0]) for vo in vos]
+        return [
+            VO(int(vo["perunVoId"]), vo["description"][0], vo["o"][0]) for vo in vos
+        ]
 
-    def get_all_facilities(self, fill_rp_ids=False) -> List[Facility]:
+    def get_all_facilities(self, fill_rp_ids=True) -> List[Facility]:
         attr_list = ["perunFacilityId", "cn", "description"]
-        if fill_rp_ids:
-            attr_list.append(self._RP_ID_ATTR)
+        rp_id_attr = self._attribute_utils.get_ldap_attr_names([self._RP_ID_ATTR])
+        if not rp_id_attr:
+            self._logger.warning("Missing RP ID attribute in ldap config")
+        else:
+            attr_list.append(rp_id_attr[0])
         facilities = self.connector.search_for_entities(
+            self._ldap_base, "(objectClass=perunFacility)", attr_list
+        )
+
+        return [
+            Facility(
+                facility["perunFacilityId"],
+                facility["cn"][0],
+                facility["description"][0],
+                facility[rp_id_attr[0]] if rp_id_attr else "",
+            )
+            for facility in facilities
+        ]
+
+    def get_groups_where_user_is_active_resource(
+        self,
+        user: Union[User, int],
+        resource: Union[Resource, int],
+        map_unique_name=True,
+    ) -> List[Group]:
+        raise AdapterSkipException
+
+    def get_facility_by_id(self, facility_id: int) -> Facility:
+        attr_list = ["perunFacilityId", "cn", "description"]
+        rp_id_attr = self._attribute_utils.get_ldap_attr_names([self._RP_ID_ATTR])
+        if not rp_id_attr:
+            self._logger.warning("Missing RP ID attribute in ldap config")
+        else:
+            attr_list.append(rp_id_attr[0])
+        facility = self.connector.search_for_entity(
             self._ldap_base,
-            "(objectClass=perunFacility)",
+            "(&(objectClass=perunFacility)(perunFacilityId=" + str(facility_id) + "))",
             attr_list,
         )
 
-        return [Facility(
+        return Facility(
             facility["perunFacilityId"],
             facility["cn"][0],
             facility["description"][0],
-            facility[self._RP_ID_ATTR] if fill_rp_ids else ""
-        ) for facility in facilities]
+            facility[rp_id_attr[0]] if rp_id_attr else "",
+        )
+
+    def get_resources_for_facility(
+        self, facility: Union[Facility, int], map_vo=True
+    ) -> List[Resource]:
+        if not isinstance(facility, Facility):
+            facility = self.get_facility_by_id(facility)
+        resources = self.connector.search_for_entities(
+            self._ldap_base,
+            "(&(objectClass=perunResource)(perunFacilityDn=perunFacilityId="
+            + str(facility.id)
+            + ","
+            + self._ldap_base
+            + "))",
+            ["perunResourceId", "cn", "perunVoId"],
+        )
+
+        if not resources:
+            raise LDAPNotExistsException(
+                "Service with spEntityId: "
+                + str(facility.id)
+                + " hasn't assigned any resource."
+            )
+
+        return [
+            Resource(
+                resource["perunResourceId"],
+                self.get_vo(vo_id=resource["perunVoId"]),
+                facility,
+                resource["cn"],
+            )
+            for resource in resources
+        ]
+
+    def get_groups_for_resource(
+        self, resource: Union[Resource, int], map_unique_name=True
+    ) -> List[Group]:
+        resource_id = self.get_object_id(resource)
+        resource = self.connector.search_for_entities(
+            self._ldap_base,
+            "(&(objectClass=perunResource)(perunResourceId=" + str(resource_id) + "))",
+            ["perunResourceId", "assignedGroupId", "perunVoId"],
+        )
+
+        if not resource:
+            raise LDAPNotExistsException(
+                "Resource with id: " + str(resource_id) + " not exists resource."
+            )
+        return self.__get_assigned_groups_ldap_resource(resource)
+
+    def get_resource_by_id(
+        self, resource_id: int, map_vo=True, map_facility=True
+    ) -> Resource:
+        resource = self.connector.search_for_entities(
+            self._ldap_base,
+            "(&(objectClass=perunResource)(perunResourceId=" + str(resource_id) + "))",
+            ["perunResourceId", "cn", "perunVoId", "perunFacilityDn"],
+        )
+        if not resource:
+            raise LDAPNotExistsException(
+                "Resource with id: " + str(resource_id) + " not exists resource."
+            )
+        facility_id = resource["perunFacilityDn"].split(",", 1)[0].split("=", 1)[1]
+        return Resource(
+            resource["perunResourceId"],
+            self.get_vo(vo_id=resource["perunVoId"]),
+            self.get_facility_by_id(facility_id),
+            resource["cn"],
+        )
+
+    def get_all_parent_groups_for_group(
+        self, group: Union[Group, int], map_unique_name=True
+    ) -> List[Group]:
+        raise AdapterSkipException
