@@ -112,10 +112,10 @@ class PerunRpcAdapter(AdapterInterface):
         )
 
     def _get_group_unique_name(
-            self,
-            attributes_api_instance: AttributesManagerApi,
-            group_name: str,
-            group_id: int,
+        self,
+        attributes_api_instance: AttributesManagerApi,
+        group_name: str,
+        group_id: int,
     ) -> str:
         attr = attributes_api_instance.get_attribute(
             group=group_id,
@@ -124,21 +124,26 @@ class PerunRpcAdapter(AdapterInterface):
         return f'{attr["value"]}:{group_name}'
 
     def _create_internal_representation_groups(
-            self,
-            input_groups: List[perun_openapi.model.group.Group],
-            converted_groups: List[Group],
-            attributes_api_instance: AttributesManagerApi,
+        self,
+        input_groups: List[perun_openapi.model.group.Group],
+        converted_groups: List[Group],
+        attributes_api_instance: AttributesManagerApi = None,
+        vo: VO = None,
     ) -> None:
         unique_ids = []
         for group in input_groups:
             if group["id"] not in unique_ids:
-                group["unique_name"] = self._get_group_unique_name(
-                    attributes_api_instance, group["name"], group["id"]
+                group["unique_name"] = (
+                    ""
+                    if not attributes_api_instance
+                    else self._get_group_unique_name(
+                        attributes_api_instance, group["name"], group["id"]
+                    )
                 )
                 converted_groups.append(
                     Group(
                         group["id"],
-                        self.get_vo(vo_id=group["vo_id"]),
+                        vo if vo else self.get_vo(vo_id=group["vo_id"]),
                         group["uuid"],
                         group["name"],
                         group["unique_name"],
@@ -148,7 +153,7 @@ class PerunRpcAdapter(AdapterInterface):
                 unique_ids.append(group["id"])
 
     def get_member_groups(
-            self, user: Union[User, int], vo: Union[VO, int]
+        self, user: Union[User, int], vo: Union[VO, int]
     ) -> List[Group]:
         with ApiClient(self._CONFIG) as api_client:
             members_api_instance = MembersManagerApi(api_client)
@@ -156,15 +161,16 @@ class PerunRpcAdapter(AdapterInterface):
             attributes_api_instance = AttributesManagerApi(api_client)
 
             converted_groups = []
-            vo_id = AdapterInterface.get_object_id(vo)
+            if not isinstance(vo, VO):
+                vo = self.get_vo(vo_id=vo)
             user_id = AdapterInterface.get_object_id(user)
-            member = members_api_instance.get_member_by_user(vo_id, user_id)
+            member = members_api_instance.get_member_by_user(vo.id, user_id)
             member_groups = []
             if member:
                 member_groups = groups_api_instance.get_all_member_groups(member["id"])
             self._create_internal_representation_groups(
-                member_groups, converted_groups, attributes_api_instance
-            )  # noqa E501
+                member_groups, converted_groups, attributes_api_instance, vo
+            )
             return converted_groups
 
     def get_sp_groups_by_facility(self, facility: Union[Facility, int]) -> List[Group]:
@@ -186,10 +192,12 @@ class PerunRpcAdapter(AdapterInterface):
             sp_groups = []
             for resource_id in resources_ids:
                 groups = resources_api_instance.get_assigned_groups(resource_id)
+                if groups:
+                    vo = self.get_vo(vo_id=groups[0]["vo_id"])
 
                 self._create_internal_representation_groups(
-                    groups, sp_groups, attributes_api_instance
-                )  # noqa E501
+                    groups, sp_groups, attributes_api_instance, vo
+                )
             return sp_groups
 
     def get_sp_groups_by_rp_id(self, rp_id: str) -> List[Group]:
@@ -259,7 +267,7 @@ class PerunRpcAdapter(AdapterInterface):
             )
 
     def get_users_groups_on_facility(
-            self, facility: Union[Facility, int], user: Union[User, int]
+        self, facility: Union[Facility, int], user: Union[User, int]
     ) -> List[Group]:
         if facility is None:
             return []
@@ -270,8 +278,10 @@ class PerunRpcAdapter(AdapterInterface):
 
             facility_id = AdapterInterface.get_object_id(facility)
             user_id = AdapterInterface.get_object_id(user)
-            users_groups_on_facility = users_api_instance.get_groups_for_facility_where_user_is_active(  # noqa E501
-                user_id, facility_id
+            users_groups_on_facility = (
+                users_api_instance.get_groups_for_facility_where_user_is_active(
+                    user_id, facility_id
+                )
             )
             converted_groups = []
             self._create_internal_representation_groups(
@@ -280,19 +290,19 @@ class PerunRpcAdapter(AdapterInterface):
             return converted_groups
 
     def get_users_groups_on_facility_by_rp_id(
-            self, rp_identifier: str, user: Union[User, int]
+        self, rp_identifier: str, user: Union[User, int]
     ) -> List[Group]:
         facility = self.get_facility_by_rp_identifier(rp_identifier)
         return self.get_users_groups_on_facility(facility, user)
 
-    def _get_rp_id(self, facility: Facility) -> str:
+    def _get_rp_id(self, facility: Union[Facility, int]) -> str:
         return self.get_facility_attributes(facility, [self._RP_ID_ATTR]).get(
             self._RP_ID_ATTR
         )
 
     # TODO test this method once SearcherAPI is supported on Devel
     def get_facilities_by_attribute_value(
-            self, attribute: dict[str, str]
+        self, attribute: dict[str, str]
     ) -> List[Facility]:
         if len(attribute) != 1:
             self._logger.warning(
@@ -323,7 +333,7 @@ class PerunRpcAdapter(AdapterInterface):
         return facilities
 
     def get_facility_attributes(
-            self, facility: Union[Facility, int], attr_names: List[str]
+        self, facility: Union[Facility, int], attr_names: List[str]
     ) -> dict[str, Union[str, Optional[int], bool, List[str], dict[str, str]]]:
         with ApiClient(self._CONFIG) as api_client:
             attributes_api_instance = AttributesManagerApi(api_client)
@@ -335,15 +345,15 @@ class PerunRpcAdapter(AdapterInterface):
             return self._get_attributes(perun_attrs)
 
     def get_user_ext_source(
-            self, ext_source_name: str, ext_source_login: str
+        self, ext_source_name: str, ext_source_login: str
     ) -> UserExtSource:
         with ApiClient(self._CONFIG) as api_client:
             users_api_instance = UsersManagerApi(api_client)
 
-            user_ext_source_perun = users_api_instance.get_user_ext_source_by_ext_login_and_ext_source_name(
-                # noqa E501
-                ext_source_name=ext_source_name,
-                ext_source_login=ext_source_login,
+            user_ext_source_perun = (
+                users_api_instance.get_user_ext_source_by_ext_login_and_ext_source_name(
+                    ext_source_name=ext_source_name, ext_source_login=ext_source_login
+                )
             )
 
             ext_source_id = user_ext_source_perun["id"]
@@ -357,7 +367,7 @@ class PerunRpcAdapter(AdapterInterface):
             return UserExtSource(ext_source_id, name, login, user)
 
     def update_user_ext_source_last_access(
-            self, user_ext_source: Union[UserExtSource, int]
+        self, user_ext_source: Union[UserExtSource, int]
     ) -> None:
         user_ext_source_id = AdapterInterface.get_object_id(user_ext_source)
 
@@ -367,23 +377,25 @@ class PerunRpcAdapter(AdapterInterface):
             users_api_instance.update_user_ext_source_last_access(user_ext_source_id)
 
     def get_user_ext_source_attributes(
-            self, user_ext_source: Union[UserExtSource, int], attr_names: List[str]
+        self, user_ext_source: Union[UserExtSource, int], attr_names: List[str]
     ) -> dict[str, Union[str, Optional[int], bool, List[str], dict[str, str]]]:
         with ApiClient(self._CONFIG) as api_client:
             attributes_api_instance = AttributesManagerApi(api_client)
 
             user_ext_source_id = AdapterInterface.get_object_id(user_ext_source)
-            perun_attrs = attributes_api_instance.get_user_ext_source_attributes_by_names(  # noqa E501
-                user_ext_source=user_ext_source_id, attr_names=attr_names
+            perun_attrs = (
+                attributes_api_instance.get_user_ext_source_attributes_by_names(
+                    user_ext_source=user_ext_source_id, attr_names=attr_names
+                )
             )
             return self._get_attributes(perun_attrs)
 
     def set_user_ext_source_attributes(
-            self,
-            user_ext_source: Union[UserExtSource, int],
-            attributes: dict[
-                str, Union[str, Optional[int], bool, List[str], dict[str, str]]
-            ],
+        self,
+        user_ext_source: Union[UserExtSource, int],
+        attributes: dict[
+            str, Union[str, Optional[int], bool, List[str], dict[str, str]]
+        ],
     ) -> None:
         with ApiClient(self._CONFIG) as api_client:
             attributes_api_instance = AttributesManagerApi(api_client)
@@ -394,10 +406,10 @@ class PerunRpcAdapter(AdapterInterface):
             )
 
     def internal_to_open_api_attrs(
-            self,
-            attributes: dict[
-                str, Union[str, Optional[int], bool, List[str], dict[str, str]]
-            ],
+        self,
+        attributes: dict[
+            str, Union[str, Optional[int], bool, List[str], dict[str, str]]
+        ],
     ) -> List[Attribute]:
         attrs_cfg = self._ATTRIBUTE_UTILS.get_specific_attrs_config_dict(
             list(attributes.keys())
@@ -418,7 +430,7 @@ class PerunRpcAdapter(AdapterInterface):
         return openapi_attributes
 
     def get_member_status_by_user_and_vo(
-            self, user: Union[User, int], vo: Union[VO, int]
+        self, user: Union[User, int], vo: Union[VO, int]
     ) -> Optional[str]:
 
         member = self.get_member_by_user(user, vo)
@@ -429,7 +441,7 @@ class PerunRpcAdapter(AdapterInterface):
         return None
 
     def is_user_in_vo_by_short_name(
-            self, user: Union[User, int], vo_short_name: str
+        self, user: Union[User, int], vo_short_name: str
     ) -> bool:
         user_id = AdapterInterface.get_object_id(user)
         if not user_id:
@@ -446,7 +458,7 @@ class PerunRpcAdapter(AdapterInterface):
         return user_status == valid_status
 
     def get_member_by_user(
-            self, user: Union[User, int], vo: Union[VO, int]
+        self, user: Union[User, int], vo: Union[VO, int]
     ) -> Optional[Member]:
         with ApiClient(self._CONFIG) as api_client:
             members_api_instance = MembersManagerApi(api_client)
@@ -458,7 +470,7 @@ class PerunRpcAdapter(AdapterInterface):
             return Member(member["id"], vo, member["status"])
 
     def get_resource_capabilities_by_facility(
-            self, facility: Union[Facility, int], user_groups: List[Union[Group, int]]
+        self, facility: Union[Facility, int], user_groups: List[Union[Group, int]]
     ) -> List[str]:
         capabilities = []
         if facility is None:
@@ -484,7 +496,7 @@ class PerunRpcAdapter(AdapterInterface):
                 resource_capabilities = attributes_api_instance.get_attribute(
                     resource=resource["id"],
                     attribute_name="urn:perun:resource:attribute-def:def"
-                                   ":capabilities",
+                    ":capabilities",
                 )["value"]
 
                 if resource_capabilities is None:
@@ -497,13 +509,13 @@ class PerunRpcAdapter(AdapterInterface):
         return capabilities
 
     def get_resource_capabilities_by_rp_id(
-            self, rp_identifier: str, user_groups: List[Union[Group, int]]
+        self, rp_identifier: str, user_groups: List[Union[Group, int]]
     ) -> List[str]:
         facility = self.get_facility_by_rp_identifier(rp_identifier)
         return self.get_resource_capabilities_by_facility(facility, user_groups)
 
     def get_facility_capabilities_by_facility(
-            self, facility: Union[Facility, int]
+        self, facility: Union[Facility, int]
     ) -> List[str]:
         if facility is None:
             return []
@@ -525,7 +537,7 @@ class PerunRpcAdapter(AdapterInterface):
         return self.get_facility_capabilities_by_facility(facility)
 
     def get_user_attributes(
-            self, user: Union[User, int], attr_names: List[str]
+        self, user: Union[User, int], attr_names: List[str]
     ) -> dict[str, Union[str, Optional[int], bool, List[str], dict[str, str]]]:
         default_attribute_name = "urn:perun:user:attribute-def:virt:loa"
         if not attr_names:
@@ -543,14 +555,16 @@ class PerunRpcAdapter(AdapterInterface):
             return self._get_attributes(perun_attrs)
 
     def get_entityless_attribute(
-            self, attr_name: str
+        self, attr_name: str
     ) -> Union[str, Optional[int], bool, List[str], dict[str, str]]:
         with ApiClient(self._CONFIG) as api_client:
             attributes_api_instance = AttributesManagerApi(api_client)
 
             attributes = {}
-            perun_attr_values = attributes_api_instance.get_entityless_attributes_by_name(
-                attr_name=attr_name
+            perun_attr_values = (
+                attributes_api_instance.get_entityless_attributes_by_name(
+                    attr_name=attr_name
+                )
             )
 
             attr_id = perun_attr_values[0].get("id")
@@ -564,7 +578,7 @@ class PerunRpcAdapter(AdapterInterface):
             return attributes
 
     def get_vo_attributes(
-            self, vo: Union[VO, int], attr_names: List[str]
+        self, vo: Union[VO, int], attr_names: List[str]
     ) -> dict[str, Union[str, Optional[int], bool, List[str], dict[str, str]]]:
         default_attribute_name = "urn:perun:vo:attribute-def:core:id"
         if not attr_names:
@@ -582,13 +596,13 @@ class PerunRpcAdapter(AdapterInterface):
             return self._get_attributes(perun_attrs)
 
     def _get_attributes(
-            self,
-            perun_attrs: List[dict[str, Union[str, int, bool, list[str], dict[str, str]]]],
+        self,
+        perun_attrs: List[dict[str, Union[str, int, bool, list[str], dict[str, str]]]],
     ) -> dict[str, dict[str, Union[str, int, bool, list[str], dict[str, str]]]]:
         attributes = {}
         for perun_attr in perun_attrs:
             perun_attr_name = (
-                    perun_attr["namespace"] + ":" + perun_attr["friendly_name"]
+                perun_attr["namespace"] + ":" + perun_attr["friendly_name"]
             )
 
             # for some reason open_api map int attributes as float
@@ -600,7 +614,7 @@ class PerunRpcAdapter(AdapterInterface):
         return attributes
 
     def get_groups_where_member_is_active(
-            self, member: Union[Member, int]
+        self, member: Union[Member, int]
     ) -> List[Group]:
         with ApiClient(self._CONFIG) as api_client:
             member_id = self.get_object_id(member)
@@ -609,14 +623,18 @@ class PerunRpcAdapter(AdapterInterface):
             perun_groups = groups_api_instance.get_groups_where_member_is_active(
                 member_id
             )
+            if isinstance(member, Member):
+                vo = member.vo
+            elif perun_groups:
+                vo = self.get_vo(vo_id=perun_groups[0]["vo_id"])
             attributes_api_instance = AttributesManagerApi(api_client)
             self._create_internal_representation_groups(
-                perun_groups, internal_groups, attributes_api_instance
+                perun_groups, internal_groups, attributes_api_instance, vo
             )
             return internal_groups
 
     def get_groups_where_user_as_member_is_active(
-            self, user: Union[User, int], vo: Union[VO, int]
+        self, user: Union[User, int], vo: Union[VO, int]
     ) -> List[Group]:
         member = self.get_member_by_user(user, vo)
         return self.get_groups_where_member_is_active(member)
@@ -651,11 +669,11 @@ class PerunRpcAdapter(AdapterInterface):
             return facilities_api_instance.create_facility(name)
 
     def set_facility_attributes(
-            self,
-            facility: Union[Facility, int],
-            attributes: dict[
-                str, Union[str, Optional[int], bool, List[str], dict[str, str]]
-            ],
+        self,
+        facility: Union[Facility, int],
+        attributes: dict[
+            str, Union[str, Optional[int], bool, List[str], dict[str, str]]
+        ],
     ) -> None:
         with ApiClient(self._CONFIG) as api_client:
             attributes_api_instance = AttributesManagerApi(api_client)
@@ -681,69 +699,130 @@ class PerunRpcAdapter(AdapterInterface):
     def is_user_perun_admin(self, user: Union[User, int]) -> bool:
         with ApiClient(self._CONFIG) as api_client:
             authz_api_instance = AuthzResolverApi(api_client)
-            if 'perunadmin' in authz_api_instance.get_user_role_names(AdapterInterface.get_object_id(user)):
+            if "perunadmin" in authz_api_instance.get_user_role_names(
+                AdapterInterface.get_object_id(user)
+            ):
                 return True
             return False
 
-    def get_vos_where_user_is_admin(self, user: Union[User, int], check_perun_admin=False) -> List[VO]:
+    def get_vos_where_user_is_admin(
+        self, user: Union[User, int], check_perun_admin=True
+    ) -> List[VO]:
         with ApiClient(self._CONFIG) as api_client:
             if check_perun_admin and self.is_user_perun_admin(user):
                 return self.get_all_vos()
             users_api_instance = UsersManagerApi(api_client)
-            vos = users_api_instance.get_vos_where_user_is_admin(AdapterInterface.get_object_id(user))
+            vos = users_api_instance.get_vos_where_user_is_admin(
+                AdapterInterface.get_object_id(user)
+            )
             return [VO(vo.id, vo.name, vo.short_name) for vo in vos]
 
-    def get_groups_where_user_is_admin(self, user: Union[User, int], check_perun_admin=False,
-                                       fill_group_unique_name=False) -> List[Group]:
+    def get_groups_where_user_is_admin(
+        self,
+        user: Union[User, int],
+        check_perun_admin=True,
+        fill_group_unique_name=True,
+    ) -> List[Group]:
         with ApiClient(self._CONFIG) as api_client:
             vos = self.get_all_vos()
             attributes_api_instance = AttributesManagerApi(api_client)
             if check_perun_admin and self.is_user_perun_admin(user):
                 groups_api_instance = GroupsManagerApi(api_client)
                 groups = groups_api_instance.get_all_groups_from_all_vos()
-                return [Group(group.id,
-                              self.__find_vo_in_list_by_id(vos, group.vo_id),
-                              group.uuid, group.name,
-                              "" if not fill_group_unique_name else self._get_group_unique_name(attributes_api_instance,
-                                                                                                group.name, group.id),
-                              group.description) for group in groups]
+                return [
+                    Group(
+                        group.id,
+                        self.__find_vo_in_list_by_id(vos, group.vo_id),
+                        group.uuid,
+                        group.name,
+                        ""
+                        if not fill_group_unique_name
+                        else self._get_group_unique_name(
+                            attributes_api_instance, group.name, group.id
+                        ),
+                        group.description,
+                    )
+                    for group in groups
+                ]
             users_api_instance = UsersManagerApi(api_client)
-            groups = users_api_instance.get_groups_where_user_is_admin(AdapterInterface.get_object_id(user))
-            return [Group(group.id,
-                          self.__find_vo_in_list_by_id(vos, group.vo_id),
-                          group.uuid, group.name,
-                          "" if not fill_group_unique_name else self._get_group_unique_name(attributes_api_instance,
-                                                                                            group.name, group.id),
-                          group.description) for group in groups]
+            groups = users_api_instance.get_groups_where_user_is_admin(
+                AdapterInterface.get_object_id(user)
+            )
+            return [
+                Group(
+                    group.id,
+                    self.__find_vo_in_list_by_id(vos, group.vo_id),
+                    group.uuid,
+                    group.name,
+                    ""
+                    if not fill_group_unique_name
+                    else self._get_group_unique_name(
+                        attributes_api_instance, group.name, group.id
+                    ),
+                    group.description,
+                )
+                for group in groups
+            ]
 
-    def get_facilities_where_user_is_admin(self, user: Union[User, int], check_perun_admin=False) -> List[Facility]:
+    def get_facilities_where_user_is_admin(
+        self, user: Union[User, int], check_perun_admin=True, fill_facility_rp_id=True
+    ) -> List[Facility]:
         with ApiClient(self._CONFIG) as api_client:
             if check_perun_admin and self.is_user_perun_admin(user):
-                return self.get_all_facilities()
+                return self.get_all_facilities(fill_facility_rp_id)
             facilities_api_instance = FacilitiesManagerApi(api_client)
             facilities = facilities_api_instance.get_facilities_where_user_is_admin(
-                AdapterInterface.get_object_id(user))
-            return [Facility(facility.id, facility.name, facility.description, facility.rp_id) for facility in
-                    facilities]
+                AdapterInterface.get_object_id(user)
+            )
+            return [
+                Facility(
+                    facility.id,
+                    facility.name,
+                    facility.description,
+                    self._get_rp_id(facility.id) if fill_facility_rp_id else "",
+                )
+                for facility in facilities
+            ]
 
-    def get_resources_where_user_is_admin(self, user: Union[User, int], check_perun_admin=False) -> List[Resource]:
+    def get_resources_where_user_is_admin(
+        self, user: Union[User, int], check_perun_admin=True, fill_facility_rp_id=True
+    ) -> List[Resource]:
         with ApiClient(self._CONFIG) as api_client:
             resources_api_instance = ResourcesManagerApi(api_client)
-            facilities = self.get_all_facilities()
+            facilities = self.get_all_facilities(fill_facility_rp_id)
             vos = self.get_all_vos()
             if check_perun_admin and self.is_user_perun_admin(user):
                 result = []
                 for vo in vos:
                     resources = resources_api_instance.get_resources(vo.id)
-                    result.extend([Resource(resource.id, vo,
-                                            self.__find_facility_in_list_by_id(facilities, resource.facility_id),
-                                            resource.name) for resource in resources])
+                    result.extend(
+                        [
+                            Resource(
+                                resource.id,
+                                vo,
+                                self.__find_facility_in_list_by_id(
+                                    facilities, resource.facility_id
+                                ),
+                                resource.name,
+                            )
+                            for resource in resources
+                        ]
+                    )
                 return result
             resources = resources_api_instance.get_all_resources_where_user_is_admin(
-                AdapterInterface.get_object_id(user))
-            return [Resource(resource.id, self.__find_vo_in_list_by_id(vos, resource.vo_id),
-                             self.__find_facility_in_list_by_id(facilities, resource.facility_id),
-                             resource.name) for resource in resources]
+                AdapterInterface.get_object_id(user)
+            )
+            return [
+                Resource(
+                    resource.id,
+                    self.__find_vo_in_list_by_id(vos, resource.vo_id),
+                    self.__find_facility_in_list_by_id(
+                        facilities, resource.facility_id
+                    ),
+                    resource.name,
+                )
+                for resource in resources
+            ]
 
     def get_all_vos(self) -> List[VO]:
         with ApiClient(self._CONFIG) as api_client:
@@ -751,14 +830,147 @@ class PerunRpcAdapter(AdapterInterface):
             vos = vos_api_instance.get_all_vos()
             return [VO(vo.id, vo.name, vo.short_name) for vo in vos]
 
-    def get_all_facilities(self, fill_rp_ids=False) -> List[Facility]:
+    def get_all_facilities(self, fill_rp_ids=True) -> List[Facility]:
         with ApiClient(self._CONFIG) as api_client:
             facilities_api_instance = FacilitiesManagerApi(api_client)
             facilities = facilities_api_instance.get_all_facilities()
-            return [Facility(facility.id,
-                             facility.name,
-                             facility.description,
-                             "" if not fill_rp_ids else self._get_rp_id(facility.id)) for facility in facilities]
+            return [
+                Facility(
+                    facility.id,
+                    facility.name,
+                    facility.description,
+                    "" if not fill_rp_ids else self._get_rp_id(facility.id),
+                )
+                for facility in facilities
+            ]
+
+    def get_groups_where_user_is_active_resource(
+        self,
+        user: Union[User, int],
+        resource: Union[Resource, int],
+        map_unique_name=True,
+    ) -> List[Group]:
+        with ApiClient(self._CONFIG) as api_client:
+            if isinstance(resource, Resource):
+                vo = resource.vo
+                resource_id = resource.id
+            else:
+                perun_vo = ResourcesManagerApi(api_client).get_vo(resource)
+                vo = VO(perun_vo.id, perun_vo.name, perun_vo.short_name)
+                resource_id = resource
+            result = []
+            perun_groups = UsersManagerApi(
+                api_client
+            ).get_groups_for_resource_where_user_is_active(
+                self.get_object_id(user), resource_id
+            )
+            self._create_internal_representation_groups(
+                perun_groups,
+                result,
+                AttributesManagerApi(api_client) if map_unique_name else "",
+                vo=vo,
+            )
+            return result
+
+    def get_facility_by_id(self, facility_id: int) -> Facility:
+        with ApiClient(self._CONFIG) as api_client:
+            facility = FacilitiesManagerApi(api_client).get_facility_by_id(facility_id)
+            return Facility(
+                facility_id,
+                facility.name,
+                facility.description,
+                self._get_rp_id(facility_id),
+            )
+
+    def get_resources_for_facility(
+        self, facility: Union[Facility, int], map_vo=True
+    ) -> List[Resource]:
+        with ApiClient(self._CONFIG) as api_client:
+            if isinstance(facility, Facility):
+                facility_id = facility.id
+            else:
+                facility_id = facility
+                facility = self.get_facility_by_id(facility)
+
+            resources = FacilitiesManagerApi(
+                api_client
+            ).get_assigned_resources_for_facility(facility_id)
+            return [
+                Resource(
+                    resource.id,
+                    self.get_vo(vo_id=resource.vo_id)
+                    if map_vo
+                    else VO(resource.vo_id, "", ""),
+                    facility,
+                    resource.name,
+                )
+                for resource in resources
+            ]
+
+    def get_groups_for_resource(
+        self, resource: Union[Resource, int], map_unique_name=True
+    ) -> List[Group]:
+        with ApiClient(self._CONFIG) as api_client:
+            if isinstance(resource, Facility):
+                resource_id = resource.id
+            else:
+                resource_id = resource
+                resource = self.get_resource_by_id(resource)
+            groups = ResourcesManagerApi(api_client).get_assigned_groups(resource_id)
+            result = []
+            self._create_internal_representation_groups(
+                groups,
+                result,
+                AttributesManagerApi(api_client) if map_unique_name else "",
+                vo=resource.vo,
+            )
+            return result
+
+    def get_resource_by_id(
+        self, resource_id: int, map_vo=True, map_facility=True
+    ) -> Resource:
+        with ApiClient(self._CONFIG) as api_client:
+            resource = ResourcesManagerApi(api_client).get_resource_by_id(resource_id)
+            facility = (
+                self.get_facility_by_id(resource.facility_id)
+                if map_facility
+                else Facility(resource.facility_id, "", "", "")
+            )
+            vo = (
+                self.get_vo(vo_id=resource.vo_id)
+                if map_vo
+                else VO(resource.vo_id, "", "")
+            )
+            return Resource(resource.id, vo, facility, resource.name)
+
+    def get_all_parent_groups_for_group(
+        self, group: Union[Group, int], map_unique_name=True
+    ) -> List[Group]:
+        with ApiClient(self._CONFIG) as api_client:
+            perun_parent_groups = []
+            perun_group = GroupsManagerApi(api_client).get_group_by_id(
+                self.get_object_id(group)
+            )
+            if isinstance(group, Group):
+                vo = group.vo
+            else:
+                vo = self.get_vo(vo_id=perun_group.vo_id)
+            if not perun_group.parent_group_id:
+                return perun_parent_groups
+
+            while perun_group.parent_group_id:
+                perun_group = GroupsManagerApi(api_client).get_parent_group(
+                    perun_group.id
+                )
+                perun_parent_groups.append(perun_group)
+            result = []
+            self._create_internal_representation_groups(
+                perun_parent_groups,
+                result,
+                AttributesManagerApi(api_client) if map_unique_name else "",
+                vo=vo,
+            )
+            return result
 
     @staticmethod
     def __find_vo_in_list_by_id(vo_list, vo_id):
