@@ -23,3 +23,6 @@ class Facility(HasIdAbstract):
                 and self.rp_id == other.rp_id
             )
         return False
+
+    def __hash__(self):
+        return hash((self.id, self.name, self.description, self.rp_id))
