@@ -4,13 +4,7 @@ from perun.connector.models.VO import VO
 
 class Group(HasIdAbstract):
     def __init__(
-        self,
-        id: int,
-        vo: VO,
-        uuid: str,
-        name: str,
-        unique_name: str,
-        description: str,
+        self, id: int, vo: VO, uuid: str, name: str, unique_name: str, description: str
     ):
         super().__init__(id)
         self.vo = vo
@@ -37,3 +31,8 @@ class Group(HasIdAbstract):
                 and self.description == other.description
             )
         return False
+
+    def __hash__(self):
+        return hash(
+            (self.id, self.vo, self.uuid, self.name, self.unique_name, self.description)
+        )
