@@ -25,3 +25,6 @@ class Resource(HasIdAbstract):
                 and self.name == other.name
             )
         return False
+
+    def __hash__(self):
+        return hash((self.id, self.name, self.vo, self.facility))
