@@ -23,3 +23,6 @@ class UserExtSource(HasIdAbstract):
                 and self.user == other.user
             )
         return False
+
+    def __hash__(self):
+        return hash((self.id, self.name, self.login, self.user))
