@@ -1,4 +1,3 @@
-
 # flake8: noqa
 
 # Import all APIs into this package.
@@ -14,20 +13,34 @@
 #   sys.setrecursionlimit(n)
 
 # Import APIs into API package:
-from perun.connector.perun_openapi.api.attributes_manager_api import AttributesManagerApi
-from perun.connector.perun_openapi.api.audit_messages_manager_api import AuditMessagesManagerApi
+from perun.connector.perun_openapi.api.attributes_manager_api import (
+    AttributesManagerApi,
+)
+from perun.connector.perun_openapi.api.audit_messages_manager_api import (
+    AuditMessagesManagerApi,
+)
 from perun.connector.perun_openapi.api.authz_resolver_api import AuthzResolverApi
 from perun.connector.perun_openapi.api.cabinet_manager_api import CabinetManagerApi
 from perun.connector.perun_openapi.api.consents_manager_api import ConsentsManagerApi
 from perun.connector.perun_openapi.api.database_manager_api import DatabaseManagerApi
-from perun.connector.perun_openapi.api.ext_sources_manager_api import ExtSourcesManagerApi
-from perun.connector.perun_openapi.api.facilities_manager_api import FacilitiesManagerApi
-from perun.connector.perun_openapi.api.facilities_manager_by_facility_name_api import FacilitiesManagerByFacilityNameApi
+from perun.connector.perun_openapi.api.ext_sources_manager_api import (
+    ExtSourcesManagerApi,
+)
+from perun.connector.perun_openapi.api.facilities_manager_api import (
+    FacilitiesManagerApi,
+)
+from perun.connector.perun_openapi.api.facilities_manager_by_facility_name_api import (
+    FacilitiesManagerByFacilityNameApi,
+)
 from perun.connector.perun_openapi.api.groups_manager_api import GroupsManagerApi
-from perun.connector.perun_openapi.api.integration_manager_api import IntegrationManagerApi
+from perun.connector.perun_openapi.api.integration_manager_api import (
+    IntegrationManagerApi,
+)
 from perun.connector.perun_openapi.api.members_manager_api import MembersManagerApi
 from perun.connector.perun_openapi.api.owners_manager_api import OwnersManagerApi
-from perun.connector.perun_openapi.api.rt_messages_manager_api import RTMessagesManagerApi
+from perun.connector.perun_openapi.api.rt_messages_manager_api import (
+    RTMessagesManagerApi,
+)
 from perun.connector.perun_openapi.api.registrar_manager_api import RegistrarManagerApi
 from perun.connector.perun_openapi.api.resources_manager_api import ResourcesManagerApi
 from perun.connector.perun_openapi.api.searcher_api import SearcherApi
