@@ -5,9 +5,7 @@ from unittest.mock import patch, MagicMock
 import pytest
 
 import perun
-from perun.connector.adapters.AdaptersManager import (
-    AdaptersManager,
-)
+from perun.connector.adapters.AdaptersManager import AdaptersManager
 from perun.connector.adapters.LdapAdapter import LdapAdapter, AdapterSkipException
 from perun.connector.adapters.PerunRpcAdapter import PerunRpcAdapter
 from perun.connector.models.User import User
