@@ -384,7 +384,10 @@ def test_users_group_on_facility_not_repeated_groups(mock_request, mock_request2
 @patch("perun.connector.connectors.LdapConnector.LdapConnector.search_for_entity")
 def test_member_status_invalid(mock_request):
     ADAPTER.connector.search_for_entity = MagicMock(return_value=None)
-    expected_error_message = "Member status is other than valid. Skipping to another adapter to get MemberStatus"
+    expected_error_message = (
+        "Member status is other than valid. "
+        + "Skipping to another adapter to get MemberStatus"
+    )
     with pytest.raises(Exception) as error:
         _ = ADAPTER.get_member_status_by_user_and_vo(USER, TEST_VO)
         assert str(error.value.args[0] == expected_error_message)
