@@ -5,9 +5,7 @@ from unittest.mock import patch, MagicMock
 import pytest
 
 from perun.connector import perun_openapi
-from perun.connector.adapters.PerunRpcAdapter import (
-    PerunRpcAdapter,
-)
+from perun.connector.adapters.PerunRpcAdapter import PerunRpcAdapter
 from perun.connector.models.Facility import Facility
 from perun.connector.models.Group import Group
 from perun.connector.models.Member import Member
@@ -179,7 +177,9 @@ def get_entity_specific_attributes(attribute_type: str):
     "perun.connector.perun_openapi.api.users_manager_api.UsersManagerApi"
     ".get_user_by_ext_source_name_and_ext_login"
 )
-def test_get_perun_user_with_middle_name_and_title_before_after(mock_request_1,):
+def test_get_perun_user_with_middle_name_and_title_before_after(
+    mock_request_1,
+):
     user_with_middle_name_title_before_after = {
         "id": 10,
         "title_before": "Ing.",
@@ -189,7 +189,6 @@ def test_get_perun_user_with_middle_name_and_title_before_after(mock_request_1,)
         "title_after": "Ph.D.",
     }
     perun_openapi.api.users_manager_api.UsersManagerApi.get_user_by_ext_source_name_and_ext_login = MagicMock(
-        # noqa E501
         return_value=user_with_middle_name_title_before_after
     )
 
@@ -203,7 +202,9 @@ def test_get_perun_user_with_middle_name_and_title_before_after(mock_request_1,)
     "perun.connector.perun_openapi.api.users_manager_api.UsersManagerApi"
     ".get_user_by_ext_source_name_and_ext_login"
 )
-def test_get_perun_user_without_middle_name_and_title_before_after(mock_request_1,):
+def test_get_perun_user_without_middle_name_and_title_before_after(
+    mock_request_1,
+):
     user_without_middle_name_title_before_after = {
         "id": 10,
         "title_before": "Ing.",
@@ -213,7 +214,6 @@ def test_get_perun_user_without_middle_name_and_title_before_after(mock_request_
         "title_after": "Ph.D.",
     }
     perun_openapi.api.users_manager_api.UsersManagerApi.get_user_by_ext_source_name_and_ext_login = MagicMock(
-        # noqa E501
         return_value=user_without_middle_name_title_before_after
     )
 
@@ -238,7 +238,6 @@ def test_user_without_middle_name_and_title_before(mock_request_1):
     }
 
     perun_openapi.api.users_manager_api.UsersManagerApi.get_user_by_ext_source_name_and_ext_login = MagicMock(
-        # noqa E501
         return_value=user_without_middle_name_title_before
     )
 
@@ -263,7 +262,6 @@ def test_user_without_middle_name_and_title_after(mock_request_1):
     }
 
     perun_openapi.api.users_manager_api.UsersManagerApi.get_user_by_ext_source_name_and_ext_login = MagicMock(
-        # noqa E501
         return_value=user_without_middle_name_title_after
     )
 
@@ -288,7 +286,6 @@ def test_user_without_middle_name_and_titles(mock_request_1):
     }
 
     perun_openapi.api.users_manager_api.UsersManagerApi.get_user_by_ext_source_name_and_ext_login = MagicMock(
-        # noqa E501
         return_value=user_without_middle_name_and_titles
     )
 
@@ -315,24 +312,26 @@ def test_user_without_middle_name_and_titles(mock_request_1):
 def test_get_member_groups_found_member_groups(
     mock_request_1, mock_request_2, mock_request_3, mock_request_4
 ):
-    perun_openapi.api.attributes_manager_api.AttributesManagerApi.get_attribute = MagicMock(
-        return_value={"value": SAMPLE_SHORT_GROUP_NAME}
-    )  # noqa E501
+    perun_openapi.api.attributes_manager_api.AttributesManagerApi.get_attribute = (
+        MagicMock(return_value={"value": SAMPLE_SHORT_GROUP_NAME})
+    )
 
     perun_openapi.api.vos_manager_api.VosManagerApi.get_vo_by_id = MagicMock(
         return_value=TEST_VO
-    )  # noqa E501
-
-    perun_openapi.api.groups_manager_api.GroupsManagerApi.get_all_member_groups = MagicMock(  # noqa E501
-        return_value=[
-            TEST_GROUP_EXTERNAL_REPRESENTATION_1,
-            TEST_GROUP_EXTERNAL_REPRESENTATION_2,
-        ]
     )
 
-    perun_openapi.api.attributes_manager_api.AttributesManagerApi.get_member_by_user = MagicMock(
-        return_value=TEST_MEMBER_INTERNAL_REPRESENTATION
-    )  # noqa E501
+    perun_openapi.api.groups_manager_api.GroupsManagerApi.get_all_member_groups = (
+        MagicMock(
+            return_value=[
+                TEST_GROUP_EXTERNAL_REPRESENTATION_1,
+                TEST_GROUP_EXTERNAL_REPRESENTATION_2,
+            ]
+        )
+    )
+
+    perun_openapi.api.attributes_manager_api.AttributesManagerApi.get_member_by_user = (
+        MagicMock(return_value=TEST_MEMBER_INTERNAL_REPRESENTATION)
+    )
 
     result_groups = ADAPTER.get_member_groups(user=TEST_USER, vo=TEST_VO)
 
@@ -347,9 +346,9 @@ def test_get_member_groups_found_member_groups(
     ".get_member_by_user"
 )
 def test_get_member_groups_member_not_found(mock_request_1):
-    perun_openapi.api.members_manager_api.MembersManagerApi.get_member_by_user = MagicMock(
-        return_value=None
-    )  # noqa E501
+    perun_openapi.api.members_manager_api.MembersManagerApi.get_member_by_user = (
+        MagicMock(return_value=None)
+    )
 
     result_groups = ADAPTER.get_member_groups(user=TEST_USER, vo=TEST_VO)
     assert result_groups == []
@@ -373,27 +372,28 @@ def test_get_sp_groups_found_sp_groups(
 ):
     test_resources = [Resource(1, None, None, None)]
 
-    perun_openapi.api.attributes_manager_api.AttributesManagerApi.get_attribute = MagicMock(
-        return_value={"value": SAMPLE_SHORT_GROUP_NAME}
-    )  # noqa E501
+    perun_openapi.api.attributes_manager_api.AttributesManagerApi.get_attribute = (
+        MagicMock(return_value={"value": SAMPLE_SHORT_GROUP_NAME})
+    )
 
     perun_openapi.api.facilities_manager_api.FacilitiesManagerApi.get_assigned_resources_for_facility = MagicMock(
-        # noqa E501
         return_value=test_resources
     )
 
-    perun_openapi.api.resources_manager_api.ResourcesManagerApi.get_assigned_groups = MagicMock(  # noqa E501
-        return_value=[
-            TEST_GROUP_EXTERNAL_REPRESENTATION_1,
-            TEST_GROUP_EXTERNAL_REPRESENTATION_1,
-            TEST_GROUP_EXTERNAL_REPRESENTATION_2,
-            TEST_GROUP_EXTERNAL_REPRESENTATION_2,
-        ]
+    perun_openapi.api.resources_manager_api.ResourcesManagerApi.get_assigned_groups = (
+        MagicMock(
+            return_value=[
+                TEST_GROUP_EXTERNAL_REPRESENTATION_1,
+                TEST_GROUP_EXTERNAL_REPRESENTATION_1,
+                TEST_GROUP_EXTERNAL_REPRESENTATION_2,
+                TEST_GROUP_EXTERNAL_REPRESENTATION_2,
+            ]
+        )
     )
 
     perun_openapi.api.vos_manager_api.VosManagerApi.get_vo_by_id = MagicMock(
         return_value=TEST_VO
-    )  # noqa E501
+    )
 
     result_groups = ADAPTER.get_sp_groups_by_facility(TEST_INTERNAL_FACILITY_1)
 
@@ -414,7 +414,6 @@ def test_get_sp_groups_no_input_facility():
 )
 def test_get_sp_groups_no_resources_found(mock_request_1):
     perun_openapi.api.facilities_manager_api.FacilitiesManagerApi.get_assigned_resources_for_facility = MagicMock(
-        # noqa E501
         return_value=[]
     )
 
@@ -433,11 +432,11 @@ def test_get_sp_groups_no_resources_found(mock_request_1):
 def test_get_group_by_name(mock_request_1, mock_request_2, mock_request_3):
     perun_openapi.api.vos_manager_api.VosManagerApi.get_vo_by_id = MagicMock(
         return_value=TEST_VO
-    )  # noqa E501
+    )
 
-    perun_openapi.api.attributes_manager_api.AttributesManagerApi.get_attribute = MagicMock(
-        return_value={"value": SAMPLE_SHORT_GROUP_NAME}
-    )  # noqa E501
+    perun_openapi.api.attributes_manager_api.AttributesManagerApi.get_attribute = (
+        MagicMock(return_value={"value": SAMPLE_SHORT_GROUP_NAME})
+    )
 
     perun_openapi.api.groups_manager_api.GroupsManagerApi.get_group_by_name = MagicMock(
         return_value=TEST_GROUP_EXTERNAL_REPRESENTATION_1
@@ -458,7 +457,7 @@ def test_get_vo_correct_arguments(mock_request_1, mock_request_2):
 
     perun_openapi.api.vos_manager_api.VosManagerApi.get_vo_by_id = MagicMock(
         return_value=test_vo
-    )  # noqa E501
+    )
     perun_openapi.api.vos_manager_api.VosManagerApi.get_vo_by_short_name = MagicMock(
         return_value=test_vo
     )
@@ -498,7 +497,7 @@ def test_get_vo_too_many_arguments():
     ".get_facilities_by_attribute"
 )
 def test_get_facility_by_rp_identifier_found_facility(mock_request_1):
-    perun_openapi.api.facilities_manager_api.FacilitiesManagerApi.get_facilities_by_attribute = MagicMock(  # noqa E501
+    perun_openapi.api.facilities_manager_api.FacilitiesManagerApi.get_facilities_by_attribute = MagicMock(
         return_value=TEST_SINGLE_PERUN_FACILITY
     )
 
@@ -512,7 +511,7 @@ def test_get_facility_by_rp_identifier_found_facility(mock_request_1):
     ".get_facilities_by_attribute"
 )
 def test_get_facility_by_rp_identifier_no_perun_attr_found(mock_request_1, caplog):
-    perun_openapi.api.facilities_manager_api.FacilitiesManagerApi.get_facilities_by_attribute = MagicMock(  # noqa E501
+    perun_openapi.api.facilities_manager_api.FacilitiesManagerApi.get_facilities_by_attribute = MagicMock(
         return_value=None
     )
     expected_error_message = "No facility with rpID 'test rp identifier' found."
@@ -530,7 +529,7 @@ def test_get_facility_by_rp_identifier_no_perun_attr_found(mock_request_1, caplo
 def test_get_facility_by_rp_identifier_multiple_perun_attrs_found(
     mock_request_1, caplog
 ):
-    perun_openapi.api.facilities_manager_api.FacilitiesManagerApi.get_facilities_by_attribute = MagicMock(  # noqa E501
+    perun_openapi.api.facilities_manager_api.FacilitiesManagerApi.get_facilities_by_attribute = MagicMock(
         return_value=TEST_MULTIPLE_PERUN_FACILITIES
     )
 
@@ -556,7 +555,6 @@ def test_get_users_groups_on_facility_multiple_groups_found(
     mock_request_1, mock_request_2, mock_request_3
 ):
     perun_openapi.api.users_manager_api.UsersManagerApi.get_groups_for_facility_where_user_is_active = MagicMock(
-        # noqa E501
         return_value=[
             TEST_GROUP_EXTERNAL_REPRESENTATION_1,
             TEST_GROUP_EXTERNAL_REPRESENTATION_2,
@@ -566,13 +564,13 @@ def test_get_users_groups_on_facility_multiple_groups_found(
         ]
     )
 
-    perun_openapi.api.attributes_manager_api.AttributesManagerApi.get_attribute = MagicMock(
-        return_value={"value": SAMPLE_SHORT_GROUP_NAME}
-    )  # noqa E501
+    perun_openapi.api.attributes_manager_api.AttributesManagerApi.get_attribute = (
+        MagicMock(return_value={"value": SAMPLE_SHORT_GROUP_NAME})
+    )
 
     perun_openapi.api.vos_manager_api.VosManagerApi.get_vo_by_id = MagicMock(
         return_value=TEST_VO
-    )  # noqa E501
+    )
 
     result_groups = ADAPTER.get_users_groups_on_facility(
         TEST_INTERNAL_FACILITY_1, TEST_USER
@@ -606,17 +604,16 @@ def test_get_users_groups_on_facility_no_groups_found(
     mock_request_1, mock_request_2, mock_request_3
 ):
     perun_openapi.api.users_manager_api.UsersManagerApi.get_groups_for_facility_where_user_is_active = MagicMock(
-        # noqa E501
         return_value=[]
     )
 
-    perun_openapi.api.attributes_manager_api.AttributesManagerApi.get_attribute = MagicMock(
-        return_value={"value": SAMPLE_SHORT_GROUP_NAME}
-    )  # noqa E501
+    perun_openapi.api.attributes_manager_api.AttributesManagerApi.get_attribute = (
+        MagicMock(return_value={"value": SAMPLE_SHORT_GROUP_NAME})
+    )
 
     perun_openapi.api.vos_manager_api.VosManagerApi.get_vo_by_id = MagicMock(
         return_value=TEST_VO
-    )  # noqa E501
+    )
 
     result_groups = ADAPTER.get_users_groups_on_facility(
         TEST_INTERNAL_FACILITY_1, TEST_USER
@@ -635,12 +632,11 @@ def test_get_users_groups_on_facility_no_groups_found(
 def test_get_facilities_by_attribute_value_correct_attribute(
     mock_request_1, mock_request_2
 ):
-    perun_openapi.api.searcher_api.SearcherApi.get_facilities = MagicMock(  # noqa E501
+    perun_openapi.api.searcher_api.SearcherApi.get_facilities = MagicMock(
         return_value=TEST_SINGLE_PERUN_FACILITY
     )
 
     perun_openapi.api.attributes_manager_api.AttributesManagerApi.get_facility_attributes_by_names = MagicMock(
-        # noqa E501
         return_value=[
             {
                 "id": "test id",
@@ -714,7 +710,6 @@ def test_get_user_ext_source(mock_request_1, mock_request_2):
     )
 
     perun_openapi.api.users_manager_api.UsersManagerApi.get_user_ext_source_by_ext_login_and_ext_source_name = MagicMock(
-        # noqa E501
         return_value=user_ext_source_external_representation
     )
 
@@ -762,7 +757,6 @@ def test_get_user_ext_source_attributes_multiple_attributes(mock_request_1):
     expected_attribute_2 = test_attribute_2.copy()
 
     perun_openapi.api.attributes_manager_api.AttributesManagerApi.get_user_ext_source_attributes_by_names = MagicMock(
-        # noqa E501
         return_value=[test_attribute_1, test_attribute_2]
     )
 
@@ -781,7 +775,6 @@ def test_get_user_ext_source_attributes_multiple_attributes(mock_request_1):
 )
 def test_get_user_ext_source_attributes_no_attributes(mock_request_1):
     perun_openapi.api.attributes_manager_api.AttributesManagerApi.get_user_ext_source_attributes_by_names = MagicMock(
-        # noqa E501
         return_value=[]
     )
 
@@ -798,9 +791,9 @@ def test_get_user_ext_source_attributes_no_attributes(mock_request_1):
 def test_get_member_status_by_user_and_vo_valid_member(mock_request_1):
     expected_status = "VALID"
     test_member_external_representation = {"id": 1, "status": expected_status}
-    perun_openapi.api.members_manager_api.MembersManagerApi.get_member_by_user = MagicMock(
-        return_value=test_member_external_representation
-    )  # noqa E501
+    perun_openapi.api.members_manager_api.MembersManagerApi.get_member_by_user = (
+        MagicMock(return_value=test_member_external_representation)
+    )
 
     result_status = ADAPTER.get_member_status_by_user_and_vo(TEST_USER, TEST_VO)
     assert result_status == MemberStatusEnum(expected_status)
@@ -811,9 +804,11 @@ def test_get_member_status_by_user_and_vo_valid_member(mock_request_1):
     ".get_member_by_user"
 )
 def test_get_member_status_by_user_and_vo_invalid_member(mock_request_1):
-    perun_openapi.api.members_manager_api.MembersManagerApi.get_member_by_user = MagicMock(  # noqa E501
-        side_effect=ApiException(
-            http_resp=HttpResponse('"name":"MemberNotExistsException"')
+    perun_openapi.api.members_manager_api.MembersManagerApi.get_member_by_user = (
+        MagicMock(
+            side_effect=ApiException(
+                http_resp=HttpResponse('"name":"MemberNotExistsException"')
+            )
         )
     )
     expected_error_message = '"name":"MemberNotExistsException"'
@@ -832,9 +827,9 @@ def test_get_member_status_by_user_and_vo_invalid_status(mock_request_1):
     invalid_status_error_msg = f'"{invalid_status}" is not a valid state.'
     test_member_external_representation = {"id": 1, "status": invalid_status}
 
-    perun_openapi.api.members_manager_api.MembersManagerApi.get_member_by_user = MagicMock(
-        return_value=test_member_external_representation
-    )  # noqa E501
+    perun_openapi.api.members_manager_api.MembersManagerApi.get_member_by_user = (
+        MagicMock(return_value=test_member_external_representation)
+    )
 
     with pytest.raises(ValueError) as error:
         _ = ADAPTER.get_member_status_by_user_and_vo(TEST_USER, TEST_VO)
@@ -857,9 +852,9 @@ def test_is_user_in_vo_valid_member(mock_request_1, mock_request_2):
         E501return_value=TEST_VO
     )
 
-    perun_openapi.api.members_manager_api.MembersManagerApi.get_member_by_user = MagicMock(
-        return_value=test_valid_member_external_representation
-    )  # noqa E501
+    perun_openapi.api.members_manager_api.MembersManagerApi.get_member_by_user = (
+        MagicMock(return_value=test_valid_member_external_representation)
+    )
 
     user_is_valid_member = ADAPTER.is_user_in_vo_by_short_name(
         TEST_USER, TEST_VO.short_name
@@ -883,9 +878,9 @@ def test_is_user_in_vo_invalid_member(mock_request_1, mock_request_2):
         return_value=TEST_VO
     )
 
-    perun_openapi.api.members_manager_api.MembersManagerApi.get_member_by_user = MagicMock(
-        return_value=test_valid_member_external_representation
-    )  # noqa E501
+    perun_openapi.api.members_manager_api.MembersManagerApi.get_member_by_user = (
+        MagicMock(return_value=test_valid_member_external_representation)
+    )
 
     user_is_valid_member = ADAPTER.is_user_in_vo_by_short_name(
         TEST_USER, TEST_VO.short_name
@@ -898,7 +893,7 @@ def test_is_user_in_vo_invalid_member(mock_request_1, mock_request_2):
     ".get_vo_by_short_name"
 )
 def test_is_user_in_vo_non_existing_vo(mock_request_1, caplog):
-    perun_openapi.api.vos_manager_api.VosManagerApi.get_vo_by_short_name = MagicMock(  # noqa E501
+    perun_openapi.api.vos_manager_api.VosManagerApi.get_vo_by_short_name = MagicMock(
         side_effect=ApiException(
             http_resp=HttpResponse('"name":"VoNotExistsException"')
         )
@@ -933,9 +928,9 @@ def test_is_user_in_vo_no_short_name_given():
     ".get_member_by_user"
 )
 def test_get_member_by_user_existing_user(mock_request_1):
-    perun_openapi.api.members_manager_api.MembersManagerApi.get_member_by_user = MagicMock(
-        return_value=TEST_MEMBER_EXTERNAL_REPRESENTATION
-    )  # noqa E501
+    perun_openapi.api.members_manager_api.MembersManagerApi.get_member_by_user = (
+        MagicMock(return_value=TEST_MEMBER_EXTERNAL_REPRESENTATION)
+    )
 
     result_member = ADAPTER.get_member_by_user(TEST_USER, TEST_VO)
 
@@ -947,9 +942,11 @@ def test_get_member_by_user_existing_user(mock_request_1):
     ".get_member_by_user"
 )
 def test_get_member_by_user_user_not_not_found_ex(mock_request_1, caplog):
-    perun_openapi.api.members_manager_api.MembersManagerApi.get_member_by_user = MagicMock(  # noqa E501
-        side_effect=ApiException(
-            http_resp=HttpResponse('"name":"MemberNotExistsException"')
+    perun_openapi.api.members_manager_api.MembersManagerApi.get_member_by_user = (
+        MagicMock(
+            side_effect=ApiException(
+                http_resp=HttpResponse('"name":"MemberNotExistsException"')
+            )
         )
     )
     short_name_missing_msg = '"name":"MemberNotExistsException"'
@@ -991,13 +988,12 @@ def test_get_resource_capabilities(mock_request_1, mock_request_2, mock_request_
     test_facility_resources = [{"id": 5}, {"id": 6}, {"id": 7}]
 
     perun_openapi.api.facilities_manager_api.FacilitiesManagerApi.get_assigned_resources_for_facility = MagicMock(
-        # noqa E501
         return_value=test_facility_resources
     )
 
-    perun_openapi.api.resources_manager_api.ResourcesManagerApi.get_assigned_groups = MagicMock(
-        side_effect=test_resource_groups
-    )  # noqa E501
+    perun_openapi.api.resources_manager_api.ResourcesManagerApi.get_assigned_groups = (
+        MagicMock(side_effect=test_resource_groups)
+    )
 
     resource_capabilities_of_groups = ["test capability 1", "test capability 2"]
     resource_capabilities_without_group = ["test capability 3"]
@@ -1008,9 +1004,9 @@ def test_get_resource_capabilities(mock_request_1, mock_request_2, mock_request_
         {"value": absent_capabilities},
     ]
 
-    perun_openapi.api.attributes_manager_api.AttributesManagerApi.get_attribute = MagicMock(
-        side_effect=external_capabilities
-    )  # noqa E501
+    perun_openapi.api.attributes_manager_api.AttributesManagerApi.get_attribute = (
+        MagicMock(side_effect=external_capabilities)
+    )
 
     expected_capabilities = ["test capability 1", "test capability 2"]
     result_capabilities = ADAPTER.get_resource_capabilities_by_facility(
@@ -1031,9 +1027,9 @@ def test_get_resource_capabilities_no_input_facility():
 )
 def test_get_facility_capabilities(mock_request_1):
     facility_capabilities = {"value": ["test capability 1", "test capability 2"]}
-    perun_openapi.api.attributes_manager_api.AttributesManagerApi.get_attribute = MagicMock(
-        return_value=facility_capabilities
-    )  # noqa E501
+    perun_openapi.api.attributes_manager_api.AttributesManagerApi.get_attribute = (
+        MagicMock(return_value=facility_capabilities)
+    )
 
     expected_capabilities = facility_capabilities["value"]
     result_capabilities = ADAPTER.get_facility_capabilities_by_facility(
@@ -1055,7 +1051,7 @@ def test_get_user_attributes_multiple_attributes(mock_request_1):
     test_user_attributes = get_entity_specific_attributes("user")
     attr_names = [attr.get("name") for attr in test_user_attributes]
 
-    perun_openapi.api.attributes_manager_api.AttributesManagerApi.get_user_attributes_by_names = MagicMock(  # noqa E501
+    perun_openapi.api.attributes_manager_api.AttributesManagerApi.get_user_attributes_by_names = MagicMock(
         return_value=test_user_attributes
     )
 
@@ -1084,7 +1080,7 @@ def test_get_user_attributes_no_attributes(mock_request_1):
         "friendly_name": "loa",
     }
 
-    perun_openapi.api.attributes_manager_api.AttributesManagerApi.get_user_attributes_by_names = MagicMock(  # noqa E501
+    perun_openapi.api.attributes_manager_api.AttributesManagerApi.get_user_attributes_by_names = MagicMock(
         return_value=[default_attr]
     )
 
@@ -1116,11 +1112,10 @@ def test_get_entityless_attribute_valid_attribute(mock_request_1, mock_request_2
     test_entityless_keys = ["entityless key 1", "entityless_key_2"]
 
     perun_openapi.api.attributes_manager_api.AttributesManagerApi.get_entityless_attributes_by_name = MagicMock(
-        # noqa E501
         return_value=test_entityless_attrs
     )
 
-    perun_openapi.api.attributes_manager_api.AttributesManagerApi.get_entityless_keys = MagicMock(  # noqa E501
+    perun_openapi.api.attributes_manager_api.AttributesManagerApi.get_entityless_keys = MagicMock(
         return_value=test_entityless_keys
     )
 
@@ -1149,7 +1144,6 @@ def test_get_entityless_attribute_attr_id_missing(mock_request_1):
     }
 
     perun_openapi.api.attributes_manager_api.AttributesManagerApi.get_entityless_attributes_by_name = MagicMock(
-        # noqa E501
         return_value=[test_entityless_attr_without_id]
     )
 
@@ -1166,7 +1160,7 @@ def test_get_vo_attributes_single_attribute(mock_request_1):
     test_vo_attributes = get_entity_specific_attributes("vo")
     attr_names = [attr.get("name") for attr in test_vo_attributes]
 
-    perun_openapi.api.attributes_manager_api.AttributesManagerApi.get_vo_attributes_by_names = MagicMock(  # noqa E501
+    perun_openapi.api.attributes_manager_api.AttributesManagerApi.get_vo_attributes_by_names = MagicMock(
         return_value=test_vo_attributes
     )
 
@@ -1195,7 +1189,7 @@ def test_get_vo_attributes_no_attributes(mock_request_1):
         "friendly_name": "id",
     }
 
-    perun_openapi.api.attributes_manager_api.AttributesManagerApi.get_vo_attributes_by_names = MagicMock(  # noqa E501
+    perun_openapi.api.attributes_manager_api.AttributesManagerApi.get_vo_attributes_by_names = MagicMock(
         return_value=[default_attr]
     )
 
@@ -1222,7 +1216,6 @@ def test_get_facility_attribute_valid_attribute(mock_request_1):
     )
 
     perun_openapi.api.attributes_manager_api.AttributesManagerApi.get_facility_attributes_by_names = MagicMock(
-        # noqa E501
         return_value=[test_facility_attribute]
     )
 
@@ -1256,7 +1249,7 @@ def test_get_attributes_empty_attributes():
     "perun.connector.perun_openapi.api.groups_manager_api.GroupsManagerApi.get_groups_where_member_is_active"
 )
 def test_get_groups_where_member_is_active_not_member(mock_request_1):
-    perun_openapi.api.groups_manager_api.GroupsManagerApi.get_groups_where_member_is_active = MagicMock(  # noqa E501
+    perun_openapi.api.groups_manager_api.GroupsManagerApi.get_groups_where_member_is_active = MagicMock(
         side_effect=ApiException(
             http_resp=HttpResponse('"name":"MemberNotExistsException"')
         )
@@ -1279,15 +1272,15 @@ def test_get_groups_where_member_is_active_not_member(mock_request_1):
 def test_get_groups_where_member_is_active(
     mock_request_1, mock_request_2, mock_request_3
 ):
-    perun_openapi.api.groups_manager_api.GroupsManagerApi.get_groups_where_member_is_active = MagicMock(  # noqa E501
+    perun_openapi.api.groups_manager_api.GroupsManagerApi.get_groups_where_member_is_active = MagicMock(
         return_value=[
             TEST_GROUP_EXTERNAL_REPRESENTATION_1,
             TEST_GROUP_EXTERNAL_REPRESENTATION_2,
         ]
     )
 
-    perun_openapi.api.attributes_manager_api.AttributesManagerApi.get_attribute = MagicMock(
-        return_value={"value": SAMPLE_SHORT_GROUP_NAME}
+    perun_openapi.api.attributes_manager_api.AttributesManagerApi.get_attribute = (
+        MagicMock(return_value={"value": SAMPLE_SHORT_GROUP_NAME})
     )
 
     perun_openapi.api.vos_manager_api.VosManagerApi.get_vo_by_id = MagicMock(
@@ -1311,7 +1304,7 @@ def test_get_groups_where_member_is_active(
     "perun.connector.perun_openapi.api.registrar_manager_api.RegistrarManagerApi.get_group_application_form"
 )
 def test_has_registration_form_group(mock_request_1):
-    perun_openapi.api.registrar_manager_api.RegistrarManagerApi.get_group_application_form = MagicMock(  # noqa E501
+    perun_openapi.api.registrar_manager_api.RegistrarManagerApi.get_group_application_form = MagicMock(
         "Application"
     )
 
@@ -1323,7 +1316,7 @@ def test_has_registration_form_group(mock_request_1):
     "perun.connector.perun_openapi.api.registrar_manager_api.RegistrarManagerApi.get_group_application_form"
 )
 def test_has_registration_form_group_no_form(mock_request_1):
-    perun_openapi.api.registrar_manager_api.RegistrarManagerApi.get_group_application_form = MagicMock(  # noqa E501
+    perun_openapi.api.registrar_manager_api.RegistrarManagerApi.get_group_application_form = MagicMock(
         return_value=[]
     )
 
@@ -1335,7 +1328,7 @@ def test_has_registration_form_group_no_form(mock_request_1):
     "perun.connector.perun_openapi.api.registrar_manager_api.RegistrarManagerApi.get_vo_application_form"
 )
 def test_has_registration_form_vo(mock_request_1):
-    perun_openapi.api.registrar_manager_api.RegistrarManagerApi.get_vo_application_form = MagicMock(  # noqa E501
+    perun_openapi.api.registrar_manager_api.RegistrarManagerApi.get_vo_application_form = MagicMock(
         "Application"
     )
 
@@ -1347,7 +1340,7 @@ def test_has_registration_form_vo(mock_request_1):
     "perun.connector.perun_openapi.api.registrar_manager_api.RegistrarManagerApi.get_vo_application_form"
 )
 def test_has_registration_form_vo_no_form(mock_request_1):
-    perun_openapi.api.registrar_manager_api.RegistrarManagerApi.get_vo_application_form = MagicMock(  # noqa E501
+    perun_openapi.api.registrar_manager_api.RegistrarManagerApi.get_vo_application_form = MagicMock(
         return_value=None
     )
 
